package com.lqkj.link.module.authority.repository;

import com.lqkj.link.module.authority.domain.UserInfo;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
import java.util.Map;

@Repository
public interface UserInfoRepository extends JpaRepository<UserInfo, Integer> {

    @Query(nativeQuery = true,
            value = "select * from user_info t where user_code = :userCode")
    UserInfo findByUserCode(@Param("userCode") String userCode);

    @Modifying
    @Query(nativeQuery = true,
            value = "update user_info set login_error_count = 0, locking = false, lock_time = null where user_id = :userId")
    void cleanLockStatus(@Param("userId") Integer userId);

    @Transactional
    @Modifying
    @Query(nativeQuery = true,
        value = "INSERT INTO user_info (user_id, user_code, display_name, password, authorization_code, head_img, " +
                    "file_save_path, has_auth, login_error_count, locking, lock_time, update_time, has_manage, refresh_resource) " +
                "VALUES (1, 'meta-link', '灵客空间', '$2a$10$e8TpJcnGtGcagLLDaL06h.W.JFtPknOl4Kxeur22rO8m7Ihz6.uzS', '87449007', " +
                "NULL, NULL, NULL, NULL, 'f', NULL, now(), 't', 'f');"
    )
    void initSuperAdmin();

    @Transactional
    @Modifying
    @Query(nativeQuery = true,
        value = "ALTER SEQUENCE user_info_user_id_seq RESTART WITH 3"
    )
    void initUserIdSeq();

    @Transactional
    @Modifying
    @Query(nativeQuery = true,
        value = "insert into user_role values (1, 1)"
    )
    void initSuperAdminRole();

    @Query(nativeQuery = true,
        value = "select count(*) = 1 " +
                "from user_info natural join user_role natural join role_authority " +
                "where user_id = :userId and authority_id = 6 "
    )
    Boolean hasAuth(Integer userId);

    @Query(nativeQuery = true,
        value = "select ai.authority_id, en_name as \"name\", route as \"path\", component, redirect, authority_name as title, icon, parent_id " +
                "from authority_info ai, role_authority ra, user_role ur, user_info ui " +
                "where ui.user_code = :userCode " +
                    "and ur.user_id = ui.user_id " +
                    "and ur.role_id = ra.role_id " +
                    "and ra.authority_id = ai.authority_id " +
                "order by ai.parent_id, ai.order_id"
    )
    List<Map<String, Object>> queryAuthWithUserCode(String userCode);

    @Query(nativeQuery = true,
        value = "with t1 as (select * from user_info where user_id != 1 " +
                    "and (:userCode = '' or user_code like concat('%', :userCode, '%')) " +
                    "and (:displayName = '' or display_name like concat('%', :displayName, '%')))," +
                "t2 as (select user_id, string_agg(role_name, ',') as role_names " +
                    "from user_role ur, role_info ri " +
                    "where ur.user_id in (select user_id from t1) and ur.role_id = ri.role_id " +
                    "group by user_id) " +
                "select t1.user_id as \"userId\", t1.user_code as \"userCode\", t1.display_name as \"displayName\", " +
                "t2.role_names as roles, to_char(t1.update_time, 'yyyy-mm-dd hh24:mi:ss') as \"updateTime\" " +
                "from t1, t2 where t1.user_id = t2.user_id order by t1.update_time desc"
    )
    Page<Map<String, Object>> pageQuery(@Param("userCode") String userCode,
                                        @Param("displayName") String displayName,
                                        Pageable pageable);

    @Query(nativeQuery = true,
        value = "select * from user_info " +
                "where user_id != 1 " +
                "and (:userCode = '' or user_code like concat('%', :userCode, '%')) " +
                "and (:displayName = '' or display_name like concat('%', :displayName, '%')) " +
                "order by update_time desc"
    )
    Page<UserInfo> pageQueryV2(@Param("userCode") String userCode,
                             @Param("displayName") String displayName,
                             Pageable pageable);

    @Query(nativeQuery = true,
        value = "select count(*) > 0 from user_info where user_code = :userCode"
    )
    Boolean hasSameUserCode(@Param("userCode") String userCode);

    @Modifying
    @Query(nativeQuery = true,
        value = "update user_info set refresh_resource = true"
    )
    void updateRefreshStatus();

    @Modifying
    @Query(nativeQuery = true,
            value = "update user_info set refresh_resource = false where user_code = :userCode"
    )
    void resourceRefreshed();

    @Modifying
    @Query(nativeQuery = true,
            value = "update user_info set autosave_time = :autosaveTime, moving_speed = :movingSpeed where user_code = :userCode"
    )
    void saveSettings(@Param("autosaveTime") Integer autosaveTime,
                      @Param("movingSpeed") Integer movingSpeed,
                      @Param("userCode") String userCode);


    @Query(nativeQuery = true,
            value = "SELECT ui.user_id, REGEXP_REPLACE(ui.user_code, '^(\\d{3})(\\d{4})(\\d+)$', '\\1****\\3') as user_code, " +
                    "ui.display_name, si.share_type FROM user_info ui " +
                    "LEFT JOIN share_info si on si.shared_user_id = ui.user_id " +
                    "WHERE si.zone_id = ?1"
    )
    List<Map<String, Object>> viewShareUser(Integer zoneId);
}
