package com.lqkj.link.module.zone.repository;

import com.lqkj.link.module.zone.domain.GeomInfo;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Repository;

import java.util.List;
import java.util.Map;

@Repository
public interface GeomInfoRepository extends JpaRepository<GeomInfo, String> {

    @Query(nativeQuery = true,
        value = "with t1 as(select zone_id, st_makepoint(" +
                    "(init_location -> 'translation' ->> 'x')\\:\\:float8, " +
                    "(init_location -> 'translation' ->> 'y')\\:\\:float8, " +
                    "(init_location -> 'translation' ->> 'z')\\:\\:float8) as init from zone_info where zone_id = :zoneId) " +
                "select gi.* from geom_info gi, t1 where gi.zone_id = t1.zone_id order by st_distance(gi.geom, t1.init) "
    )
    List<GeomInfo> findAllByZoneId(Integer zoneId);

    @Modifying
    @Query(nativeQuery = true,
        value = "with t1 as(insert into geom_info(geom_id, zone_id, model_id, layer_id, geom_name, building_id, floor, room_id, geom, properties, locking) " +
                "select nextval('geom_info_geom_id_seq'), :zoneId, model_id, layer_id, geom_name, building_id, floor, room_id, geom, properties, locking " +
                "from geom_info where zone_id = :templateId order by geom_id returning *)" +
                "select min(t1.geom_id) - min(gi.geom_id) from t1, geom_info gi where gi.geom_id = :templateId"
    )
    Integer createWithTemplateReturnIncrement(@Param("templateId") Integer templateId,
                                              @Param("zoneId") Integer zoneId);

    @Modifying
    @Query(nativeQuery = true,
            value = "insert into geom_info(geom_id, zone_id, model_id, layer_id, geom_name, building_id, floor, room_id, geom, properties, locking) " +
                    "select nextval('geom_info_geom_id_seq'), :zoneId, model_id, layer_id, geom_name, building_id, floor, room_id, geom, properties, locking " +
                    "from geom_info where zone_id = :templateId returning *"
    )
    List<GeomInfo> createWithTemplate(@Param("templateId") Integer templateId,
                                              @Param("zoneId") Integer zoneId);

    @Modifying
    @Query(nativeQuery = true,
        value = "with t1 as(update geom_info set building_id = building_id + :increment where zone_id = :zoneId and building_id is not null)" +
                "update geom_info set room_id = room_id + :increment where zone_id = :zoneId and room_id is not null"
    )
    void updateBuildingIdAndRoomId(@Param("zoneId") Integer zoneId,
                                   @Param("increment") Integer increment);

    @Query(nativeQuery = true,
        value = "select * from geom_info where zone_id = :zoneId and layer_id is not null"
    )
    List<GeomInfo> queryHasLayer(@Param("zoneId") Integer zoneId);

    @Modifying
    @Query(nativeQuery = true,
        value = "update geom_info set layer_id = layer_id + :increment where zone_id = :zoneId and layer_id is not null"
    )
    void updateLayerId(@Param("zoneId") Integer zoneId,
                       @Param("increment") Integer increment);

    @Query(nativeQuery = true,
        value = "select geom_id, geom_name, layer_id, locking from geom_info where zone_id = :zoneId order by layer_id, geom_id"
    )
    List<Map<String, Object>> readLayer(@Param("zoneId") Integer zoneId);

    @Query(nativeQuery = true,
        value = "select count(*) > 0 from geom_info where zone_id = :zoneId"
    )
    Boolean hasGeom(@Param("zoneId") Integer zoneId);

    @Modifying
    @Query(nativeQuery = true,
        value = "delete from geom_info where zone_id = :zoneId"
    )
    void deleteAllByZoneId(Integer zoneId);

    @Query(nativeQuery = true,
        value = "SELECT *  " +
                "FROM geom_info  " +
                "WHERE zone_id = :zoneId AND navigation = 't' " +
                "ORDER BY  " +
                "    CASE  " +
                "        WHEN geom_name ~ '^[\\u4e00-\\u9fa5]' THEN 0  " +
                "        ELSE 1  " +
                "    END, " +
                "    geom_name;"
    )
    List<GeomInfo> getNavigationInfo(Integer zoneId);
}
