package com.lqkj.link.module.zone.repository;

import com.lqkj.link.module.zone.domain.LikesInfo;
import com.lqkj.link.module.zone.domain.MaterialInfo;
import com.lqkj.link.module.zone.domain.ModelCategory;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Repository;

import java.util.List;

@Repository
public interface MaterialInfoRepository extends JpaRepository<MaterialInfo, Integer> {

    /**
     * 判断是否重名
     * @param materialId
     * @param materialName
     * @return
     */
    @Query(nativeQuery = true,
            value = "select count(*) > 0 from material_info where material_name = :materialName and material_id != :materialId"
    )
    boolean hasSameNameWithoutOne(@Param("materialId") Integer materialId,
                                  @Param("materialName")String materialName);


    /**
     * 判断是否重名
     * @param materialName
     * @return
     */
    @Query(nativeQuery = true,
            value = "select count(*) > 0 from material_info where material_name = :materialName"
    )
    boolean hasSameName(@Param("materialName") String materialName);


    @Query(nativeQuery = true,
            value = "select * from material_info where " +
                    "(:materialName = '' or material_name like concat('%', :materialName, '%')) " +
                    "and (:materialType is null or material_type = :materialType) " +
                    "and (:userId is null or user_id = :userId) " +
                    "order by update_time desc"
    )
    Page<MaterialInfo> pageQuery(@Param("materialName") String materialName,
                                 @Param("materialType") Integer materialType,
                                 Pageable pageable,
                                 @Param("userId") Integer userId);
    @Query(nativeQuery = true,
            value = "select * from material_info where (:materialName = '' or material_name like concat('%', :materialName, '%'))"
    )
    List<MaterialInfo> findAllByName(@Param("materialName") String materialName);
}
