package com.lqkj.link.module.zone.repository;

import com.lqkj.link.module.zone.domain.ShareInfo;
import com.lqkj.link.module.zone.domain.ZoneInfo;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Repository;

import java.util.List;

@Repository
public interface ShareInfoRepository extends JpaRepository<ShareInfo, Integer> {


    /**
     * 根据zoneId和sharedUserId查询
     * @param zoneId
     * @param userId
     * @return
     */
    @Query(nativeQuery = true,
            value = "SELECT * FROM share_info WHERE zone_id = ?1 AND shared_user_id = ?2"
    )
    List<ShareInfo> findByZoneIdAndSharedUserId(Integer zoneId, Integer userId);

    /**
     * 根据zoneId查询
     * @param zoneId
     * @return
     */
    @Query(nativeQuery = true,
            value = "SELECT * FROM share_info WHERE zone_id = ?1 and ( accept_status ISNULL OR accept_status = TRUE ) "
    )
    List<ShareInfo> findByZoneId(Integer zoneId);

    @Modifying
    @Query(nativeQuery = true,
            value = "DELETE FROM share_info WHERE zone_id = ?1"
    )
    void deleteByZoneId(Integer zoneId);

    @Modifying
    @Query(nativeQuery = true,
            value = "UPDATE share_info SET share_time = NOW(), accept_status = null, share_type = ?3 WHERE zone_id = ?1 AND shared_user_id = ?2"
    )
    void updateShareTime(Integer zoneId, Integer userId, Integer shareType);

    @Modifying
    @Query(nativeQuery = true,
            value = "UPDATE share_info SET share_type = ?2 WHERE zone_id = ?1 and shared_user_id = ?3"
    )
    void updateShareType(Integer zoneId, Integer shareType, Integer sharedUserId);
}
