package com.lqkj.link.module.zone.repository;

import com.lqkj.link.module.zone.domain.TextureInfo;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Repository;

import java.util.List;

@Repository
public interface TextureInfoRepository extends JpaRepository<TextureInfo, Integer> {

    /**
     * 判断是否重名
     * @param textureId
     * @param textureName
     * @return
     */
    @Query(nativeQuery = true,
            value = "select count(*) > 0 from texture_info where texture_name = :textureName and texture_id != :textureId"
    )
    boolean hasSameNameWithoutOne(@Param("textureId") Integer textureId,
                                  @Param("textureName")String textureName);


    /**
     * 判断是否重名
     * @param textureName
     * @return
     */
    @Query(nativeQuery = true,
            value = "select count(*) > 0 from texture_info where texture_name = :textureName"
    )
    boolean hasSameName(@Param("textureName") String textureName);


    @Query(nativeQuery = true,
            value = "select * from texture_info where " +
                    "(:textureName = '' or texture_name like concat('%', :textureName, '%')) " +
                    "and texture_type = :textureType " +
                    "and (:userId is null or user_id = :userId) " +
                    "order by update_time"
    )
    Page<TextureInfo> pageQuery(@Param("textureName") String textureName,
                                 @Param("textureType") Integer textureType,
                                 Pageable pageable,
                                 @Param("userId") Integer userId);

    @Query(nativeQuery = true,
            value = "select * from texture_info where " +
                    "(:name = '' or texture_name like concat('%', :name, '%')) " +
                    "and user_id = :userId "
    )
    List<TextureInfo> getAll(String name, Integer userId);
}
