package com.lqkj.link.util;

import com.aliyun.oss.OSS;
import com.aliyun.oss.OSSClientBuilder;
import com.aliyun.oss.model.ListObjectsV2Request;
import com.aliyun.oss.model.ListObjectsV2Result;
import com.aliyun.oss.model.OSSObjectSummary;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.LocalTime;
import java.time.LocalDate;
import java.util.List;
import java.util.UUID;
import java.util.concurrent.Callable;

@Component
public class AliOSSUtils {
 
    /**
     * 注入AliProperties
     */
    private final AliProperties aliProperties;

    private final ThreadPoolUtil threadPoolUtil;

    public AliOSSUtils(AliProperties aliProperties, ThreadPoolUtil threadPoolUtil) {
        this.aliProperties = aliProperties;
        this.threadPoolUtil = threadPoolUtil;
    }

    /**
     * 实现上传图片到OSS
     */
    public String upload(File file) {
        String originalFilename = file.getName();
        String fileName = "file/" + LocalDate.now() + "/" + UUID.randomUUID() + originalFilename.substring(originalFilename.lastIndexOf("."));
        //上传文件到 OSS
        try {
            Thread.sleep(100);
        } catch (InterruptedException e) {
            throw new RuntimeException(e);
        }
        OSS ossClient = new OSSClientBuilder().build(aliProperties.getEndpoint(), aliProperties.getAccessKeyId(), aliProperties.getAccessKeySecret());
        threadPoolUtil.getTaskExecutor().execute(() -> {
            ossClient.putObject(aliProperties.getBucketName(), fileName, file);
            ossClient.shutdown();
        });
        //文件访问路径
        String url = aliProperties.getOsspath().split("//")[0] + "//" + aliProperties.getBucketName() + "." + aliProperties.getOsspath().split("//")[1] + "/" + fileName;
        // 关闭ossClient

        return url;// 把上传到oss的路径返回
    }

    public String upload(MultipartFile file) throws IOException {
        // 获取上传的文件的输入流
        try {
            InputStream inputStream = file.getInputStream();
            // 避免文件覆盖
            String originalFilename = file.getOriginalFilename();
            String fileName = "file/" + LocalDate.now() + "/" + UUID.randomUUID() + originalFilename.substring(originalFilename.lastIndexOf("."));
            //上传文件到 OSS
            try {
                Thread.sleep(100);
            } catch (InterruptedException e) {
                throw new RuntimeException(e);
            }
            OSS ossClient = new OSSClientBuilder().build(aliProperties.getEndpoint(), aliProperties.getAccessKeyId(), aliProperties.getAccessKeySecret());
            threadPoolUtil.getTaskExecutor().execute(() -> {
                ossClient.putObject(aliProperties.getBucketName(), fileName, inputStream);
                ossClient.shutdown();
            });
            //文件访问路径
            return aliProperties.getOsspath().split("//")[0] + "//" + aliProperties.getBucketName() + "." + aliProperties.getOsspath().split("//")[1] + "/" + fileName;
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }


    public String addModel(MultipartFile file, String path) {
        // 获取上传的文件的输入流
        try {
            InputStream inputStream = file.getInputStream();
            // 避免文件覆盖
            String originalFilename = file.getOriginalFilename();
            String fileName = path + UUID.randomUUID() + originalFilename.substring(originalFilename.lastIndexOf("."));
            //上传文件到 OSS
            OSS ossClient = new OSSClientBuilder().build(aliProperties.getEndpoint(), aliProperties.getAccessKeyId(), aliProperties.getAccessKeySecret());
            threadPoolUtil.getTaskExecutor().execute(() -> {
                ossClient.putObject(aliProperties.getBucketName(), fileName, inputStream);
                ossClient.shutdown();
            });
            //文件访问路径
            return aliProperties.getOsspath().split("//")[0] + "//" + aliProperties.getBucketName() + "." + aliProperties.getOsspath().split("//")[1] + "/" + fileName;
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }

    public Long ossCheckCapacity(String path) {
        OSS ossClient = new OSSClientBuilder().build(aliProperties.getEndpoint(), aliProperties.getAccessKeyId(), aliProperties.getAccessKeySecret());
        return calculateFolderLength(ossClient, aliProperties.getBucketName(), path);
    }

    private static long calculateFolderLength(OSS ossClient, String bucketName, String folder) {
        long size = 0L;
        ListObjectsV2Result result = null;
        do {
            // MaxKey默认值为100，最大值为1000。
            ListObjectsV2Request request = new ListObjectsV2Request(bucketName).withPrefix(folder).withMaxKeys(1000);
            if (result != null) {
                request.setContinuationToken(result.getNextContinuationToken());
            }
            result = ossClient.listObjectsV2(request);
            List<OSSObjectSummary> sums = result.getObjectSummaries();
            for (OSSObjectSummary s : sums) {
                size += s.getSize();
            }
        } while (result.isTruncated());
        return size;
    }

    public void deleteModel(String path) {
        OSS ossClient = new OSSClientBuilder().build(aliProperties.getEndpoint(), aliProperties.getAccessKeyId(), aliProperties.getAccessKeySecret());
        String prefix = aliProperties.getOsspath().split("//")[0] + "//" + aliProperties.getBucketName() + "." + aliProperties.getOsspath().split("//")[1] + "/";
        ossClient.deleteObject(aliProperties.getBucketName(), path.replace(prefix, ""));
    }

}