/*==============================================================*/
/* DBMS name:      PostgreSQL 9.x                               */
/* Created on:     2024/4/18 20:54:02                           */
/*==============================================================*/



/*==============================================================*/
/* Table: audit_record                                          */
/*==============================================================*/
create table audit_record (
    record_id            SERIAL               not null,
    zone_id              INT4                 null,
    user_id              INT4                 null,
    auth_status          INT4                 null,
    apply_time           TIMESTAMP            null,
    auth_time            TIMESTAMP            null,
    delete_status        BOOL                 null,
    delete_time          TIMESTAMP            null,
    constraint PK_AUDIT_RECORD primary key (record_id)
);

comment on table audit_record is
'审核记录：audit_record';

comment on column audit_record.record_id is
'记录ID：record_id';

comment on column audit_record.zone_id is
'审核作品ID：zone_id';

comment on column audit_record.user_id is
'审核员用户ID：user_id';

comment on column audit_record.auth_status is
'审核状态：auth_status，1待审核，2通过，3拒绝，4删除，5撤销';

comment on column audit_record.apply_time is
'申请审核时间：apply_time';

comment on column audit_record.auth_time is
'审核时间：auth_time';

comment on column audit_record.delete_status is
'是否删除：delete_status';

comment on column audit_record.delete_time is
'删除时间：delete_time';

/*==============================================================*/
/* Table: notice_info                                           */
/*==============================================================*/
create table notice_info (
    info_id              SERIAL               not null,
    bulletin_id          INT4                 null,
    content              TEXT                 null,
    create_time          TIMESTAMP            null,
    user_id              INT4                 null,
    has_view             BOOL                 null,
    view_time            TIMESTAMP            null,
    type                 INT4                 null,
    constraint PK_NOTICE_INFO primary key (info_id)
);

comment on table notice_info is
'通知信息：notice_info';

comment on column notice_info.info_id is
'信息ID：info_id';

comment on column notice_info.bulletin_id is
'公告ID：bulletin_id';

comment on column notice_info.content is
'信息内容：content';

comment on column notice_info.create_time is
'信息时间：create_time';

comment on column notice_info.user_id is
'通知用户ID：user_id';

comment on column notice_info.has_view is
'是否已查看：has_view';

comment on column notice_info.view_time is
'查看时间：view_time';

comment on column notice_info.type is
'类型：type，1更新日志，2系统公告, 3审核通知';

/*==============================================================*/
/* Table: authority_info                                        */
/*==============================================================*/
create table authority_info (
    authority_id         INT4                 not null,
    parent_id            INT4                 null,
    authority_name       VARCHAR(255)         null,
    en_name              VARCHAR(255)         null,
    route                VARCHAR(255)         null,
    component            VARCHAR(255)         null,
    redirect             VARCHAR(255)         null,
    icon                 VARCHAR(255)         null,
    order_id             INT4                 null,
    constraint PK_AUTHORITY_INFO primary key (authority_id)
);

comment on table authority_info is
'权限信息：authority_info';

comment on column authority_info.authority_id is
'权限ID：authority_id';

comment on column authority_info.parent_id is
'父权限ID：parent_id';

comment on column authority_info.authority_name is
'权限名称：authority_name';

comment on column authority_info.en_name is
'英文名：en_name';

comment on column authority_info.route is
'路由地址：route';

comment on column authority_info.component is
'组件：component';

comment on column authority_info.redirect is
'重定向地址：redirect';

comment on column authority_info.icon is
'图标：icon';

comment on column authority_info.order_id is
'排序：order_id';

insert into authority_info values
    (1, null, '模板管理', 'Template', '/Template', '#', '/Template/TemplateManage', null, 1),
    (2, 1, '模板管理', 'TemplateManage', 'TemplateManage', 'views/Template/TemplateManage', null, 'ant-design:dashboard-filled', 2),
    (3, null, '资源管理', 'Resource', '/Resource', '#', '/Resource/ResourceManage', null, 3),
    (4, 3, '资源管理', 'ResourceManage', 'ResourceManage', 'views/Resource/ResourceManage', null, 'carbon:skill-level-advanced', 4),
    (5, null, '审核管理', 'Audit', '/Audit', '#', '/Audit/AuditManage', null, 5),
    (6, 5, '审核管理', 'AuditManage', 'AuditManage', 'views/Audit/AuditManage', null, 'ri:function-fill', 6),
    (7, null, '权限管理', 'Authority', '/Authority', '#', '/Authority/AuditManage', 'eos-icons:role-binding', 7),
    (8, 7, '用户管理', 'User', 'User', 'views/Authority/User', null, null, 8),
    (9, 7, '角色管理', 'Role', 'Role', 'views/Authority/Role', null, null, 9),
    (10, null, '系统设置', 'System', '/System', '#', '/System/SystemSetting', null, 10),
    (11, 10, '系统设置', 'SystemSetting', 'SystemSetting', 'views/System/SystemSetting', null, 'ic:outline-webhook', 11);

/*==============================================================*/
/* Table: bulletin_info                                         */
/*==============================================================*/
create table bulletin_info (
    info_id              SERIAL               not null,
    content              TEXT                 null,
    create_time          TIMESTAMP            null,
    info_type            INTEGER              null,
    constraint PK_BULLETIN_INFO primary key (info_id)
);

comment on table bulletin_info is
'公告信息表：bulletin_info';

comment on column bulletin_info.info_id is
'信息编号：info_id';

comment on column bulletin_info.content is
'信息内容：content';

comment on column bulletin_info.create_time is
'发布时间：create_time';

comment on column bulletin_info.info_type is
'公告类型：info_type，1更新日志，2系统公告';

/*==============================================================*/
/* Table: config_info                                           */
/*==============================================================*/
create table config_info (
    config_key           VARCHAR(64)          not null,
    config_value         TEXT                 null,
    content_type         VARCHAR(50)          null,
    constraint PK_CONFIG_INFO primary key (config_key)
);

comment on table config_info is
'产品配置：config_info';

comment on column config_info.config_key is
'配置信息key：config_key';

comment on column config_info.config_value is
'配置信息值：config_value';

comment on column config_info.content_type is
'信息类型：content_type';

insert into config_info values
('banner', '[]', 'application/json'),
('direction', '', 'String'),
('login_bg', '', 'image/png');

/*==============================================================*/
/* Table: geom_info                                             */
/*==============================================================*/
create table geom_info (
    geom_id              VARCHAR(64)               not null,
    zone_id              INT4                 null,
    model_id             INT4                 null,
    layer_id             VARCHAR(64)                 null,
    geom_name            VARCHAR(255)         null,
    building_id          INT4                 null,
    floor                INT4                 null,
    room_id              INT4                 null,
    geom                 geometry             null,
    properties           jsonb                null,
    locking              BOOL                 null,
    trans                jsonb                null,
    constraint PK_GEOM_INFO primary key (geom_id)
);

comment on table geom_info is
'空间信息：geom_info';

comment on column geom_info.geom_id is
'元素ID：geom_id';

comment on column geom_info.zone_id is
'区域ID：zone_id';

comment on column geom_info.model_id is
'模型ID：model_id';

comment on column geom_info.layer_id is
'图层ID：layer_id';

comment on column geom_info.geom_name is
'元素名称：geom_name';

comment on column geom_info.building_id is
'大楼ID：building_id';

comment on column geom_info.floor is
'楼层：floor';

comment on column geom_info.room_id is
'房间ID：room_id';

comment on column geom_info.geom is
'空间信息：geom';

comment on column geom_info.properties is
'属性信息：properties';

comment on column geom_info.locking is
'锁定：locking';

comment on column geom_info.trans is
'变换：trans';

/*==============================================================*/
/* Table: layer_info                                            */
/*==============================================================*/
create table layer_info (
    layer_id             VARCHAR(64)               not null,
    zone_id              INT4                 null,
    layer_name           VARCHAR(255)         null,
    locking              BOOL                 null,
    constraint PK_LAYER_INFO primary key (layer_id)
);

comment on table layer_info is
'图层信息：layer_info';

comment on column layer_info.layer_id is
'图层ID：layer_id';

comment on column layer_info.zone_id is
'区域ID：zone_id';

comment on column layer_info.layer_name is
'图层名称：layer_name';

comment on column layer_info.locking is
'是否锁定：locking';

/*==============================================================*/
/* Table: model_category                                        */
/*==============================================================*/
create table model_category (
    category_id          SERIAL               not null,
    user_id              INT4                 null,
    icon                 VARCHAR(1024)         null,
    category_name        VARCHAR(255)         null,
    order_id             INT4                 null,
    compress_file_path   VARCHAR(1024)        null,
    compress_file_name   VARCHAR(1024)        null,
    constraint PK_MODEL_CATEGORY primary key (category_id)
);

comment on table model_category is
'模型分类：model_category';

comment on column model_category.category_id is
'分类ID：category_id';

comment on column model_category.user_id is
'用户ID：user_id';

comment on column model_category.icon is
'图标：icon';

comment on column model_category.category_name is
'分类名称：category_name';

comment on column model_category.order_id is
'排序：order_id';

comment on column model_category.compress_file_path is
'模型压缩文件路径：compress_file_path';

comment on column model_category.compress_file_name is
'模型压缩文件名称：compress_file_name';

/*==============================================================*/
/* Table: model_info                                            */
/*==============================================================*/
create table model_info (
    model_id             SERIAL               not null,
    category_id          INT4                 null,
    model_name           VARCHAR(255)         null,
    json_path            VARCHAR(255)         null,
    texture_path         VARCHAR(255)         null,
    order_id             INT4                 null,
    original_path        VARCHAR(255)         null,
    model_icon           VARCHAR(255)         null,
    template_id          int4                 null,
    constraint PK_MODEL_INFO primary key (model_id)
);

comment on table model_info is
'模型信息：model_info';

comment on column model_info.model_id is
'模型ID：model_id';

comment on column model_info.category_id is
'分类ID：category_id';

comment on column model_info.model_name is
'模型名称：model_name';

comment on column model_info.json_path is
'空间信息文件地址：json_path';

comment on column model_info.texture_path is
'贴图文件地址：texture_path';

comment on column model_info.order_id is
'排序：order_id';

comment on column model_info.original_path is
'原始模型文件地址：original_path';

comment on column model_info.model_icon is
'模型图标文件地址：model_icon';

comment on column model_info.template_id is
'模板ID：template_id';

/*==============================================================*/
/* Table: role_authority                                        */
/*==============================================================*/
create table role_authority (
    role_id              INT4                 not null,
    authority_id         INT4                 not null,
    constraint PK_ROLE_AUTHORITY primary key (role_id, authority_id)
);

comment on table role_authority is
'角色权限信息：role_authority';

comment on column role_authority.role_id is
'角色ID：role_id';

comment on column role_authority.authority_id is
'权限ID：authority_id';

insert into role_authority select 1,  generate_series (1, 11);

/*==============================================================*/
/* Table: role_info                                             */
/*==============================================================*/
create table role_info (
    role_id              SERIAL               not null,
    role_name            VARCHAR(255)         null,
    en_name              VARCHAR(255)         null,
    update_time          TIMESTAMP            null,
    constraint PK_ROLE_INFO primary key (role_id)
);

comment on table role_info is
'角色信息：role_info';

comment on column role_info.role_id is
'角色ID：role_id';

comment on column role_info.role_name is
'角色名称：role_name';

comment on column role_info.en_name is
'英文名称：en_name';

comment on column role_info.update_time is
'更新时间：update_time';

insert into role_info values
    (1, '超级管理员', 'superAdmin', now());

select nextval('role_info_role_id_seq');

/*==============================================================*/
/* Table: share_info                                            */
/*==============================================================*/
create table share_info (
    record_id            SERIAL               not null,
    zone_id              INT4                 null,
    user_id              INT4                 null,
    share_code           VARCHAR(64)          null,
    share_time           TIMESTAMP            null,
    can_use              INT4                 null,
    constraint PK_SHARE_INFO primary key (record_id)
);

comment on table share_info is
'分享记录：share_info';

comment on column share_info.record_id is
'记录ID：record_id';

comment on column share_info.zone_id is
'区域ID：zone_id';

comment on column share_info.user_id is
'用户ID：user_id';

comment on column share_info.share_code is
'随机序号：share_code';

comment on column share_info.share_time is
'分享时间：share_time';

comment on column share_info.can_use is
'有效期（天）：can_use';

/*==============================================================*/
/* Table: user_info                                             */
/*==============================================================*/
create table user_info (
    user_id              SERIAL               not null,
    user_code            VARCHAR(255)         null,
    display_name         VARCHAR(255)         null,
    password             VARCHAR(255)         null,
    authorization_code   VARCHAR(64)          null,
    head_img             VARCHAR(1024)        null,
    file_save_path       VARCHAR(1024)        null,
    has_auth             BOOL                 null,
    login_error_count    INT4                 null,
    locking              BOOL                 null,
    lock_time            TIMESTAMP            null,
    update_time          TIMESTAMP            null,
    has_manage           BOOLEAN              null,
    refresh_resource     BOOLEAN              not null default false,
    constraint PK_USER_INFO primary key (user_id)
);

comment on table user_info is
'用户信息：user_info';

comment on column user_info.user_id is
'用户ID：user_id';

comment on column user_info.user_code is
'登录账号：user_code';

comment on column user_info.display_name is
'显示名称：display_name';

comment on column user_info.password is
'登录密码：password';

comment on column user_info.authorization_code is
'授权码：authorization_code';

comment on column user_info.head_img is
'头像：head_img';

comment on column user_info.file_save_path is
'文件保存路径：file_save_path';

comment on column user_info.has_auth is
'是否有审核权限：has_auth';

comment on column user_info.login_error_count is
'登录错误次数：login_error_count';

comment on column user_info.locking is
'是否锁定：locking';

comment on column user_info.lock_time is
'锁定时间：lock_time';

comment on column user_info.update_time is
'更新时间：update_time';

comment on column user_info.has_manage is
'能否进入管理后台：has_manage';

comment on column user_info.refresh_resource is
'是否需要刷新资源：refresh_resource';

/*==============================================================*/
/* Table: user_role                                             */
/*==============================================================*/
create table user_role (
    role_id              INT4                 not null,
    user_id              INT4                 not null,
    constraint PK_USER_ROLE primary key (role_id, user_id)
);

comment on table user_role is
'用户角色：user_role';

comment on column user_role.role_id is
'角色ID：role_id';

comment on column user_role.user_id is
'用户ID：user_id';

/*==============================================================*/
/* Table: view_record                                           */
/*==============================================================*/
create table view_record (
    record_id            SERIAL               not null,
    user_id              INT4                 null,
    zone_id              INT4                 null,
    create_time          TIMESTAMP            null,
    constraint PK_VIEW_RECORD primary key (record_id)
);

comment on table view_record is
'作品查看记录：view_record';

comment on column view_record.record_id is
'记录ID：record_id';

comment on column view_record.user_id is
'用户ID：user_id';

comment on column view_record.zone_id is
'区域ID：zone_id';

comment on column view_record.create_time is
'记录时间：create_time';

/*==============================================================*/
/* Table: zone_info                                             */
/*==============================================================*/
create table zone_info (
    zone_id              SERIAL               not null,
    user_id              INT4                 null,
    zone_name            VARCHAR(255)         null,
    init_location        jsonb                null,
    thumbnail            VARCHAR(1024)        null,
    auth_status          INT4                 null,
    update_time          TIMESTAMP            null,
    share_count          INT4                 null default 0,
    view_count           INT4                 null default 0,
    order_id             INT4                 null,
    template_file_name   VARCHAR(1024)        null,
    template_file_path   VARCHAR(1024)        null,
    template_use         int4                 null,
    constraint PK_ZONE_INFO primary key (zone_id)
);

comment on table zone_info is
'区域信息：zone_info';

comment on column zone_info.zone_id is
'区域ID：zone_id';

comment on column zone_info.user_id is
'用户ID：user_id';

comment on column zone_info.zone_name is
'区域名称：zone_name';

comment on column zone_info.init_location is
'初始坐标：init_location';

comment on column zone_info.thumbnail is
'缩略图：thumbnail';

comment on column zone_info.auth_status is
'审核状态：auth_status，0未申请，1待审核，2通过，3拒绝';

comment on column zone_info.update_time is
'更新时间：update_time';

comment on column zone_info.share_count is
'分享次数：share_count';

comment on column zone_info.view_count is
'查看次数：view_count';

comment on column zone_info.order_id is
'排序：order_id';

comment on column zone_info.template_file_name is
'模板压缩文件名称：template_file_name';

comment on column zone_info.template_file_path is
'模板压缩文件路径：template_file_path';

comment on column zone_info.template_use is
'模板使用次数：template_use';

alter table audit_record
    add constraint FK_AUDIT_RECORD_REF_USER foreign key (user_id)
        references user_info (user_id)
        on delete cascade on update cascade;

alter table audit_record
    add constraint FK_AUDIT_RECORD_REF_ZONE foreign key (zone_id)
        references zone_info (zone_id)
        on delete cascade on update cascade;

alter table notice_info
    add constraint FK_NOTICE_REF_BULLETIN foreign key (bulletin_id)
        references bulletin_info (info_id)
        on delete cascade on update cascade;

alter table notice_info
    add constraint FK_NOTICE_REF_USER foreign key (user_id)
        references user_info (user_id)
        on delete cascade on update cascade;

alter table authority_info
    add constraint FK_AUTHORITY_REF_SELF foreign key (parent_id)
        references authority_info (authority_id)
        on delete cascade on update cascade;

alter table geom_info
    add constraint FK_GEOM_REF_LAYER foreign key (layer_id)
        references layer_info (layer_id)
        on delete set null on update cascade;

alter table geom_info
    add constraint FK_GEOM_REF_MODEL foreign key (model_id)
        references model_info (model_id)
        on delete cascade on update cascade;

alter table geom_info
    add constraint FK_GEOM_REF_ZONE foreign key (zone_id)
        references zone_info (zone_id)
        on delete cascade on update cascade;

alter table layer_info
    add constraint FK_LAYER_REF_ZONE foreign key (zone_id)
        references zone_info (zone_id)
        on delete cascade on update cascade;

alter table model_category
    add constraint FK_MODEL_CATEGORY_REF_USER foreign key (user_id)
        references user_info (user_id)
        on delete cascade on update cascade;

alter table model_info
    add constraint FK_MODEL_REF_MODEL_CATEGORY foreign key (category_id)
        references model_category (category_id)
        on delete cascade on update cascade;

alter table role_authority
    add constraint FK_ROLE_AUTH_REF_AUTH foreign key (authority_id)
        references authority_info (authority_id)
        on delete cascade on update cascade;

alter table role_authority
    add constraint FK_ROLE_AUTH_REF_ROLE foreign key (role_id)
        references role_info (role_id)
        on delete cascade on update cascade;

alter table share_info
    add constraint FK_SHARE_REF_USER foreign key (user_id)
        references user_info (user_id)
        on delete cascade on update cascade;

alter table share_info
    add constraint FK_SHARE_REF_ZONE foreign key (zone_id)
        references zone_info (zone_id)
        on delete cascade on update cascade;

alter table user_role
    add constraint FK_USER_ROLE_REF_ROLE foreign key (role_id)
        references role_info (role_id)
        on delete cascade on update cascade;

alter table user_role
    add constraint FK_USER_ROLE_REF_USER foreign key (user_id)
        references user_info (user_id)
        on delete cascade on update cascade;

alter table view_record
    add constraint FK_VIEW_RECORD_REF_USER foreign key (user_id)
        references user_info (user_id)
        on delete cascade on update cascade;

alter table view_record
    add constraint FK_VIEW_RECORD_REF_ZONE foreign key (zone_id)
        references zone_info (zone_id)
        on delete cascade on update cascade;

alter table zone_info
    add constraint FK_ZONE_REF_USER foreign key (user_id)
        references user_info (user_id)
        on delete cascade on update cascade;

alter table geom_info
    add column if not exists pics varchar(1024),
    add column if not exists video_url varchar(1024),
    add column if not exists audio_url varchar(1024),
    add column if not exists brief text,
    add column if not exists navigation bool default false,
    add column if not exists navigation_end varchar(100);

comment on column geom_info.pics is '图片地址：pics';
comment on column geom_info.video_url is '视频文件地址：video_url';
comment on column geom_info.audio_url is '音频文件地址：audio_url';
comment on column geom_info.brief is '简介：brief';
comment on column geom_info.navigation is '是否导航：navigation';
comment on column geom_info.navigation_end is '导航终点：navigation_end';


ALTER TABLE model_info
ALTER COLUMN texture_path TYPE VARCHAR(5000);
